opentelemetry_exporter (opentelemetry_exporter v1.0.0-rc.3) View Source
This is the module providing the OpenTelemetry protocol for exporting traces. It can be configured through its application environment, the OS environment or directly through a map of options passed when setting up the exporter in the batch processor.
opentelemetry_exporter application enevironment options are:
otlp_endpoint: The URL to send traces and metrics to, for traces the pathv1/tracesis appended to the path in the URL.otlp_traces_endpoint: URL to send only traces to. This takes precedence for exporting traces and the path of the URL is kept as is, no suffix is appended.otlp_headers: Additional headers to add to export requests.otlp_traces_headers: Additional headers to add to only trace export %% requests.
There also corresponding OS environment variables can also set those configuration values:
OTEL_EXPORTER_OTLP_ENDPOINTOTEL_EXPORTER_OTLP_TRACES_ENDPOINTOTEL_EXPORTER_OTLP_HEADERSOTEL_EXPORTER_OTLP_TRACES_HEADERS
Link to this section Summary
Functions
Export OTLP protocol telemery data to the configured endpoints.
Initialize the exporter based on the provided configuration.
Shutdown the exporter.